<?php
/**
*
* Antivirus Site Protection. An extension for the phpBB Forum Software package.
*
* @copyright (c) 2017 Siteguarding Ltd <https://www.siteguarding.com>
* @license GNU General Public License, version 2 (GPL-2.0)
*
*/

namespace siteguarding\antivirus\acp;

class antivirus_module
{
	
	public $u_action;
	
	public function main($id, $mode)
	{
		
		global $phpbb_container,$request,$user;
		
		$action					= $request->variable('action', '');
		$domain					= $request->variable('domain', '');
		$email					= $request->variable('email', '');
		
		$tab_id					= $request->variable('tab', '');
		$scan					= $request->variable('scan', '');
		
		$update_email			= $request->variable('email_set', '');
		$update_acc_key			= $request->variable('access_key_set', '');
		$update 				= $request->variable('update_set', '');
		
		switch ($mode)
		{
			case 'antivirus':
			
				$antivirus_controller = $phpbb_container->get('siteguarding.antivirus.controller.acp.antivirus');
				
				$registration = $antivirus_controller->check_registration();
				
				if($registration == true)
				{
					$this->page_title = 'ACP_ANTIVIRUS_TITLE';
					
					$this->tpl_name = 'acp_antivirus_main';
					
					$antivirus_controller->set_page_url($this->u_action);
					
					if (!$antivirus_controller->check_access_key())
					{
						trigger_error($user->lang('ACP_WRONG_KEY'),E_USER_WARNING);
					}
					
					$antivirus_controller->antivirus_page($tab_id);
					
				} else
				{
					$this->page_title = 'ACP_ANTIVIRUS_REGISTRATION';
					
					if($action == 'ConfirmRegistration')
					{
						$result = $antivirus_controller->registration($domain, $email);
						
						switch($result)
						{
							case 'registered':
								
								trigger_error($user->lang('ACP_DOMAIN_REGISTERED') . adm_back_link($this->u_action),E_USER_NOTICE);
								
							case 'not_found':
							
								trigger_error(sprintf($user->lang('ACP_DOMAIN_NOT_FOUND') . adm_back_link($this->u_action),$domain),E_USER_WARNING);
								
							case 'already_registered':
						
								trigger_error(sprintf($user->lang('ACP_DOMAIN_ALREADY_REGISTERED') . adm_back_link($this->u_action),$domain, $email),E_USER_WARNING);
								
							case 'curl_error':
								
								trigger_error($user->lang('ACP_CURL_ERROR') . adm_back_link($this->u_action),E_USER_WARNING);
							
						}
					}
					
					$this->tpl_name = 'acp_antivirus_registration';
					
					$antivirus_controller->set_page_url($this->u_action);
					
					$antivirus_controller->registration_page();
					
				}
				
				switch ($action)
				{
					case 'avp_refresh_status':
					$antivirus_controller->avp_refresh_status();
					break;
				}
				
				if($scan == 'StartScan')
				{
					$this->page_title = 'ACP_SCAN';
					
					$this->tpl_name = 'acp_antivirus_scan';
					
					$antivirus_controller->set_page_url($this->u_action);
					
					$result = $antivirus_controller->scan();
					
					switch($result)
					{
						case 'empty_domain':
							trigger_error($user->lang('EMPTY_DOMAIN') . adm_back_link($this->u_action),E_USER_WARNING);
						
						case 'empty_session_key':
							trigger_error($user->lang('EMPTY_SESS_KEY') . adm_back_link($this->u_action),E_USER_WARNING);
						
						case 'empty_scan_path':
							trigger_error($user->lang('EMPTY_SCAN_PATH') . adm_back_link($this->u_action),E_USER_WARNING);
						
						case 'empty_pack_file':
							trigger_error($user->lang('EMPTY_PACK_FILE') . adm_back_link($this->u_action),E_USER_WARNING);
						
						case 'cant_upload':
							trigger_error($user->lang('CANT_UPLOAD') . adm_back_link($this->u_action),E_USER_WARNING);
						
						case 'big_pack_file':
							trigger_error($user->lang('BIG_PACK_FILE') . adm_back_link($this->u_action),E_USER_WARNING);
						
						case 'another_scanning_process':
							trigger_error($user->lang('ANOTHER_SCANNING_PROCESS') . adm_back_link($this->u_action),E_USER_WARNING);
						
						case 'couldnt_open_zip':
							trigger_error($user->lang('COULDNT_OPEN_ZIP') . adm_back_link($this->u_action),E_USER_WARNING);
							
						case 'finish':
							$antivirus_controller->antivirus_scan_page();
							break;
					}
				}

			break;
			
			case 'settings':
			
				$this->page_title = 'ACP_ANTIVIRUS_SETTINGS';
				
				$this->tpl_name = 'acp_settings';
				
				$settings_controller = $phpbb_container->get('siteguarding.antivirus.controller.acp.settings');
				
				$settings_controller->set_page_url($this->u_action);
				
				if($update == 'update_settings')
				{
					$settings_controller->update_settings($update_email,$update_acc_key);
					
					$antivirus_controller = $phpbb_container->get('siteguarding.antivirus.controller.acp.antivirus');
					
					$antivirus_controller->avp_refresh_status();
				}
				
				$settings_controller->settings_page();
				
			break;
		}
	}
}
