<?php
/**
 *
 * Antivirus Site Protection. An extension for the phpBB Forum Software package.
 *
 * @copyright (c) 2017 Siteguarding Ltd <https://www.siteguarding.com>
 * @license GNU General Public License, version 2 (GPL-2.0)
 *
 */

namespace siteguarding\antivirus\controller\acp;

class antivirus
{
	public static  $antivirus_version = '1.0';
	public static  $antivirus_platform = 'phpbb';
	public static  $antivirus_cms = 'phpbb';
	
	protected $report_key;
	
	protected $u_action;

	protected $sql_helper;
	
	protected $helper;
	
	protected $template;
	
	protected $user;
	
	protected $dir_helper;
	
	protected $php_ext;
	
	protected $antivirus_helper;
	
	public function __construct(\siteguarding\antivirus\core\sql_helper $sql_helper, \siteguarding\antivirus\core\helper $helper, \phpbb\template\template $template, \phpbb\user $user,\siteguarding\antivirus\core\dir_helper $dir_helper, $php_ext, \siteguarding\antivirus\core\antivirus_helper $antivirus_helper)
	{
		$this->sql_helper = $sql_helper;
		
		$this->helper = $helper;
		
		$this->template = $template;
		
		$this->php_ext = $php_ext;
		
		$this->dir_helper = $dir_helper;
		
		$this->user = $user;
		
		$this->antivirus_helper = $antivirus_helper;
	}
	
	public function check_registration()
	{
		$data = $this->sql_helper->get_extra_params(array('domain','access_key','email'));
		
 		if($data != false && count($data) > 0)
		{
			return true;
			
		} else 
		{
			return false;
		}
	}
	
	public function scan()
	{
		if (strtoupper(substr(PHP_OS, 0, 3)) === 'WIN')
		{
			define(DIRSEP, '\\');
		} else 
		{
			define(DIRSEP, '/');
		}
		
		$data = $this->sql_helper->get_extra_params(array('domain','access_key','email'));

		$params = $this->helper->get_license_info();
		
		$scan_path = dirname(__FILE__);
		$scan_path = str_replace(DIRSEP.'ext'.DIRSEP.'siteguarding'.DIRSEP.'antivirus'.DIRSEP.'controller'.DIRSEP.'acp', DIRSEP, $scan_path);
		
		$work_dir = str_replace(DIRSEP.'controller'.DIRSEP.'acp',DIRSEP,dirname(__FILE__));
		
		$report_key = md5($data['domain'] . '-' . rand(1,1000) . '-' . time());
		$this->report_key = trim($report_key);
		
		$scanner = $this->antivirus_helper;
		
		$scanner->antivirus_version = self::$antivirus_version;
		$scanner->antivirus_platform = self::$antivirus_platform;
		$scanner->antivirus_cms = self::$antivirus_cms;
		
		$scanner->work_dir = $work_dir;
		$scanner->tmp_dir = $work_dir.'tmp'.DIRSEP;
		$scanner->membership = trim($params['membership']);
		$scanner->scan_path = $scan_path;
		$scanner->access_key = trim($data['access_key']);
		$scanner->domain = trim($data['domain']);
		$scanner->email = trim($data['email']);
		$scanner->session_report_key = $this->report_key;
		
		return $scanner->scanner();
	}
	
	public function antivirus_scan_page()
	{
		$data = $this->sql_helper->get_extra_params(array('domain','access_key'));
		
		$post_data = base64_encode(json_encode(array(
    				'domain' => $data['domain'],
    				'access_key' => $data['access_key'],
    				'session_report_key' => $this->report_key)));
		
		$this->template->assign_vars(array(
			'EXT_IMG_PATH'			=> $this->dir_helper->get_img_path(),
			'SESSION_REPORT_KEY'	=> $this->report_key,
			'U_ACTION'				=> $this->u_action,
			'URL'					=> $this->helper->siteguarding_server,
			'REPORT_DATA'			=> $post_data,
		));
	}
	
	public function check_access_key()
	{
		$params = $this->helper->get_license_info();
		$data = $this->sql_helper->get_extra_params(array('access_key'));
		
		if($params['access_key'] != $data['access_key'])
		{
			return false;
		} else 
		{
			return true;
		}
	}
		
	public function antivirus_page($tab_id = 0)
	{
		$params = $this->helper->get_license_info();
		
		$ant_scan_tab = '';
		$reports_tab = '';
		$help_tab = '';
		
		switch($tab_id )
		{
			case 0:
				$status_tab = 'active ';
				break;
			case 1:
				$ant_scan_tab = 'active ';
				break;
			case 2:
				$reports_tab = 'active ';
				break;
			case 3:
				$help_tab = 'active ';
				break;
		}
		
		$timestamp = $this->sql_helper->get_extra_params(array('cache_license_info_time'));
		$timestamp = $timestamp['cache_license_info_time'];
		
		$this->template->assign_vars(array(
			'STATUS_TAB'		=> $status_tab,
			'ANT_SCAN_TAB'		=> $ant_scan_tab,
			'REPORTS_TAB'		=> $reports_tab,
			'HELP_TAB'			=> $help_tab,
			'MEMBERSHIP'		=> $params['membership'],
			'EXT_IMG_PATH'		=> $this->dir_helper->get_img_path(),
			'NAV_LINK'			=> append_sid("index." . $this->php_ext . "?" . preg_replace("/&tab=.|action=(avp_refresh_status&)/",'',$this->user->page['query_string'])),
			'SEC_STATUS'		=> sprintf($this->user->lang['ACP_SECURITY_STATUS'],$params['domain']),
			'TIMESTAMP'			=> date("Y-m-d H:i:s",$timestamp),
			'U_ACTION'			=> $this->u_action,
		));
		
		switch ($params['membership'])
		{
			case 'trial':
				$this->template->assign_vars(array(
					'STATUS_VERSION_TYPE_MES'	=>	'yellow',
					'STATUS_VERSION_TYPE_ICON'	=>	'info',
					'STATUS_VERSION_HEADER'		=>	sprintf($this->user->lang['STATUS_VERSION_HEADER_TRIAL'],$params['latest_version']),
					'STATUS_VERSION_MES'		=> sprintf($this->user->lang['STATUS_VERSION_MES_TEXT'],$params['scans'],$params['exp_date']),
					'STATUS_VERSION_BUT_TEXT'	=> $this->user->lang['STATUS_VERSION_BUT_TEXT_TEXT'],
					'STATUS_VERSION_BUT_URL'	=> 'https://www.siteguarding.com/en/buy-service/antivirus-site-protection',
					'STATUS_VERSION_HELP_TEXT'	=> '',
					'STATUS_VERSION_ID'			=> "id_".rand(1,10000).'_'.rand(1,10000),
					'STATUS_VERSION_URL_TARGET' => true,
				));	
			break;
			case 'pro':
				$this->template->assign_vars(array(
					'STATUS_VERSION_TYPE_MES'	=>	'green',
					'STATUS_VERSION_TYPE_ICON'	=>	'checkmark box',
					'STATUS_VERSION_HEADER'		=>	sprintf($this->user->lang['STATUS_VERSION_HEADER_PRO'],$params['latest_version']),
					'STATUS_VERSION_MES'		=> sprintf($this->user->lang['STATUS_VERSION_MES_TEXT'],$params['scans'],$params['exp_date']),
					'STATUS_VERSION_BUT_TEXT'	=> '',
					'STATUS_VERSION_BUT_URL'	=> '',
					'STATUS_VERSION_HELP_TEXT'	=> '',
					'STATUS_VERSION_ID'			=> "id_".rand(1,10000).'_'.rand(1,10000),
					'STATUS_VERSION_URL_TARGET' => false,
				));
			break;
			case 'free':
				$this->template->assign_vars(array(
					'STATUS_VERSION_TYPE_MES'	=>	'negative',
					'STATUS_VERSION_TYPE_ICON'	=>	'warning sign',
					'STATUS_VERSION_HEADER'		=>	sprintf($this->user->lang['STATUS_VERSION_HEADER_FREE'],$params['latest_version']),
					'STATUS_VERSION_MES'		=> sprintf($this->user->lang['STATUS_VERSION_MES_FREE'],$params['scans']),
					'STATUS_VERSION_BUT_TEXT'	=> $this->user->lang['STATUS_VERSION_BUT_TEXT_TEXT'],
					'STATUS_VERSION_BUT_URL'	=> 'https://www.siteguarding.com/en/buy-service/antivirus-site-protection',
					'STATUS_VERSION_HELP_TEXT'	=> '',
					'STATUS_VERSION_ID'			=> "id_".rand(1,10000).'_'.rand(1,10000),
					'STATUS_VERSION_URL_TARGET' => true,
				));
			break;
		}
		
		if (count($params['reports']) > 0)
		{
			if ($params['last_scan_files_counters']['main'] == 0 && $params['last_scan_files_counters']['heuristic'] == 0)
			{
				$this->template->assign_vars(array(
					'STATUS_FILES_TYPE_MES'			=> 'green',
					'STATUS_FILES_TYPE_ICON'		=> 'checkmark box',
					'STATUS_FILES_HEADER'			=> $this->user->lang['STATUS_FILES_HEADER_CLEAN'],
					'STATUS_FILES_MES'				=> $this->user->lang['STATUS_FILES_MES_CLEAN'],
					'STATUS_FILES_BUT_TEXT'			=> '',
					'STATUS_FILES_BUT_URL'			=> '',
					'STATUS_FILES_HELP_TEXT'		=> '',
					'STATUS_FILES_ID'				=> "id_".rand(1,10000).'_'.rand(1,10000),
					'STATUS_FILES_URL_TARGET' 		=> false,
				));
			}
			
			if ($params['filemonitoring']['status'] == 0)
			{
				$extra_clean_text 	= '';
				$link_clean 		= 'https://www.siteguarding.com/en/services/malware-removal-service';
				$button_text		= $this->user->lang['STATUS_FILES_BUT_TEXT_NO_SUB'];
			} else 
			{
				$extra_clean_text 	= $this->user->lang['STATUS_FILES_HELP_TEXT_HAS_SUB'];
				$link_clean 		= 'https://www.siteguarding.com/en/contacts';
				$button_text 		= $this->user->lang['STATUS_FILES_HELP_TEXT_HAS_SUB'];
			}
			
			if ($params['last_scan_files_counters']['main'] > 0)
			{
				$this->template->assign_vars(array(
					'STATUS_FILES_TYPE_MES'			=> 'negative',
					'STATUS_FILES_TYPE_ICON'		=> 'warning sign',
					'STATUS_FILES_HEADER'			=> $this->user->lang['STATUS_FILES_HEADER_MAIN'],
					'STATUS_FILES_MES'				=> $this->user->lang['STATUS_FILES_MES_MAIN'],
					'STATUS_FILES_BUT_TEXT'			=> $button_text,
					'STATUS_FILES_BUT_URL'			=> $link_clean,
					'STATUS_FILES_HELP_TEXT'		=> $extra_clean_text,
					'STATUS_FILES_ID'				=> "id_".rand(1,10000).'_'.rand(1,10000),
					'STATUS_FILES_URL_TARGET' 		=> false,
				));
			} else if ($params['last_scan_files_counters']['heuristic'] > 0)
			{
				$this->template->assign_vars(array(
					'STATUS_FILES_TYPE_MES'			=> 'yellow',
					'STATUS_FILES_TYPE_ICON'		=> 'info',
					'STATUS_FILES_HEADER'			=> $this->user->lang['STATUS_FILES_HEADER_HEURISTIC'],
					'STATUS_FILES_MES'				=> $this->user->lang['STATUS_FILES_MES_MAIN'],
					'STATUS_FILES_BUT_TEXT'			=> $button_text,
					'STATUS_FILES_BUT_URL'			=> $link_clean,
					'STATUS_FILES_HELP_TEXT'		=> $extra_clean_text,
					'STATUS_FILES_ID'				=> "id_".rand(1,10000).'_'.rand(1,10000),
					'STATUS_FILES_URL_TARGET' 		=> false,
				));
			}
			
		} else 
		{
			$this->template->assign_vars(array(
				'STATUS_FILES_TYPE_MES'			=> 'negative',
				'STATUS_FILES_TYPE_ICON'		=> 'warning sign',
				'STATUS_FILES_HEADER'			=> $this->user->lang['STATUS_FILES_HEADER_NOT_ANALYZED'],
				'STATUS_FILES_MES'				=> $this->user->lang['STATUS_FILES_MES_NOT_ANALYZED'],
				'STATUS_FILES_BUT_TEXT'			=> $this->user->lang['STATUS_FILES_BUT_TEXT_NOT_ANALYZED'],
				'STATUS_FILES_BUT_URL'			=> append_sid("index." . $this->php_ext . "?" . preg_replace("/&tab=.|action=(avp_refresh_status&)/",'',$this->user->page['query_string']) . "&tab=1"),
				'STATUS_FILES_HELP_TEXT'		=> '',
				'STATUS_FILES_ID'				=> "id_".rand(1,10000).'_'.rand(1,10000),
				'STATUS_FILES_URL_TARGET' 		=> false,
			));
		}
		
		if ($params['blacklist']['google'] != 'ok')
		{
			$this->template->assign_vars(array(
				'STATUS_BLACKLIST_TYPE_MES'			=> 'negative',
				'STATUS_BLACKLIST_TYPE_ICON'		=> 'warning sign',
				'STATUS_BLACKLIST_HEADER'			=> $this->user->lang['STATUS_BLACKLIST_HEADER'],
				'STATUS_BLACKLIST_MES'				=> sprintf($this->user->lang['STATUS_BLACKLIST_MES_BLCKL'],$params['blacklist']['google']),
				'STATUS_BLACKLIST_BUT_TEXT'			=> $this->user->lang['STATUS_BLACKLIST_BUT_TEXT_BLCKL'],
				'STATUS_BLACKLIST_BUT_URL'			=> 'https://www.siteguarding.com/en/services/malware-removal-service',
				'STATUS_BLACKLIST_HELP_TEXT'		=> '',
				'STATUS_BLACKLIST_ID'				=> "id_".rand(1,10000).'_'.rand(1,10000),
				'STATUS_BLACKLIST_URL_TARGET' 		=> true,
			));
		} else 
		{
			$this->template->assign_vars(array(
				'STATUS_BLACKLIST_TYPE_MES'			=> 'green',
				'STATUS_BLACKLIST_TYPE_ICON'		=> 'checkmark box',
				'STATUS_BLACKLIST_HEADER'			=> $this->user->lang['STATUS_BLACKLIST_HEADER'],
				'STATUS_BLACKLIST_MES'				=> $this->user->lang['STATUS_BLACKLIST_MES_NOT_BLCKL'],
				'STATUS_BLACKLIST_BUT_TEXT'			=> '',
				'STATUS_BLACKLIST_BUT_URL'			=> '',
				'STATUS_BLACKLIST_HELP_TEXT'		=> '',
				'STATUS_BLACKLIST_ID'				=> "id_".rand(1,10000).'_'.rand(1,10000),
				'STATUS_BLACKLIST_URL_TARGET' 		=> false,
			));
		}
		
		if ($params['filemonitoring']['status'] == 0)
		{
			$this->template->assign_vars(array(
				'STATUS_MONITOR_TYPE_MES'			=> 'negative',
				'STATUS_MONITOR_TYPE_ICON'			=> 'warning sign',
				'STATUS_MONITOR_HEADER'				=> $this->user->lang['STATUS_MONITOR_HEADER'],
				'STATUS_MONITOR_MES'				=> $this->user->lang['STATUS_MONITOR_MES_NO_SUB'],
				'STATUS_MONITOR_BUT_TEXT'			=> $this->user->lang['STATUS_MONITOR_BUT_TEXT_NO_SUB'],
				'STATUS_MONITOR_BUT_URL'			=> 'https://www.siteguarding.com/en/protect-your-website',
				'STATUS_MONITOR_HELP_TEXT'			=> $this->user->lang['STATUS_MONITOR_HELP_TEXT_NO_SUB'],
				'STATUS_MONITOR_ID'					=> "id_".rand(1,10000).'_'.rand(1,10000),
				'STATUS_MONITOR_URL_TARGET' 		=> true,
			));
		} else
		{
			$this->template->assign_vars(array(
				'STATUS_MONITOR_TYPE_MES'			=> 'green',
				'STATUS_MONITOR_TYPE_ICON'			=> 'checkmark box',
				'STATUS_MONITOR_HEADER'				=> $this->user->lang['STATUS_MONITOR_HEADER'],
				'STATUS_MONITOR_MES'				=> sprintf($this->user->lang['STATUS_MONITOR_MES_HAS_SUB'],$params['filemonitoring']['plan'],$params['filemonitoring']['exp_date']),
				'STATUS_MONITOR_BUT_TEXT'			=> '',
				'STATUS_MONITOR_BUT_URL'			=> '',
				'STATUS_MONITOR_HELP_TEXT'			=> $this->user->lang['STATUS_MONITOR_HELP_TEXT_HAS_SUB'],
				'STATUS_MONITOR_ID'					=> "id_".rand(1,10000).'_'.rand(1,10000),
				'STATUS_MONITOR_URL_TARGET' 		=> false,
			));
		}
		
		if(!$this->check_firewall())
		{
			$this->template->assign_vars(array(
				'STATUS_FIREWALL_TYPE_MES'			=> 'negative',
				'STATUS_FIREWALL_TYPE_ICON'			=> 'warning sign',
				'STATUS_FIREWALL_HEADER'			=> $this->user->lang['STATUS_FIREWALL_HEADER_NO'],
				'STATUS_FIREWALL_MES'				=> $this->user->lang['STATUS_FIREWALL_MES_NO'],
				'STATUS_FIREWALL_BUT_TEXT'			=> $this->user->lang['STATUS_MONITOR_BUT_TEXT_NO_SUB'],
				'STATUS_FIREWALL_BUT_URL'			=> 'https://www.siteguarding.com/en/protect-your-website',
				'STATUS_FIREWALL_HELP_TEXT'			=> $this->user->lang['STATUS_FIREWALL_HELP_TEXT_NO'],
				'STATUS_FIREWALL_ID'				=> "id_".rand(1,10000).'_'.rand(1,10000),
				'STATUS_FIREWALL_URL_TARGET' 		=> true,
			));
		} else 
		{
			$this->template->assign_vars(array(
				'STATUS_FIREWALL_TYPE_MES'			=> 'green',
				'STATUS_FIREWALL_TYPE_ICON'			=> 'checkmark box',
				'STATUS_FIREWALL_HEADER'			=> $this->user->lang['STATUS_FIREWALL_HEADER_NO'],
				'STATUS_FIREWALL_MES'				=> $this->user->lang['STATUS_FIREWALL_MES_YES'],
				'STATUS_FIREWALL_BUT_TEXT'			=> '',
				'STATUS_FIREWALL_BUT_URL'			=> '',
				'STATUS_FIREWALL_HELP_TEXT'			=> $this->user->lang['STATUS_FIREWALL_HELP_TEXT_YES'],
				'STATUS_FIREWALL_ID'				=> "id_".rand(1,10000).'_'.rand(1,10000),
				'STATUS_FIREWALL_URL_TARGET' 		=> true,
			));
		}
		
		if ( !isset($params['filemonitoring']['remote_backup_status']) || $params['filemonitoring']['remote_backup_status'] == 0)
		{
			$this->template->assign_vars(array(
				'STATUS_BACKUP_TYPE_MES'			=> 'negative',
				'STATUS_BACKUP_TYPE_ICON'			=> 'warning sign',
				'STATUS_BACKUP_HEADER'				=> $this->user->lang['STATUS_BACKUP_HEADER_NO'],
				'STATUS_BACKUP_MES'					=> $this->user->lang['STATUS_BACKUP_MES_NO'],
				'STATUS_BACKUP_BUT_TEXT'			=> $this->user->lang['STATUS_MONITOR_BUT_TEXT_NO_SUB'],
				'STATUS_BACKUP_BUT_URL'				=> 'https://www.siteguarding.com/en/importance-of-website-backup',
				'STATUS_BACKUP_HELP_TEXT'			=> $this->user->lang['STATUS_BACKUP_HELP_TEXT_NO'],
				'STATUS_BACKUP_ID'					=> "id_".rand(1,10000).'_'.rand(1,10000),
				'STATUS_BACKUP_URL_TARGET' 			=> true,
			));
		} else 
		{
			$this->template->assign_vars(array(
				'STATUS_BACKUP_TYPE_MES'			=> 'green',
				'STATUS_BACKUP_TYPE_ICON'			=> 'checkmark box',
				'STATUS_BACKUP_HEADER'				=> $this->user->lang['STATUS_BACKUP_HEADER_NO'],
				'STATUS_BACKUP_MES'					=> sprintf($this->user->lang['STATUS_BACKUP_MES_YES'],$params['filemonitoring']['plan'],$params['filemonitoring']['exp_date']),
				'STATUS_BACKUP_BUT_TEXT'			=> '',
				'STATUS_BACKUP_BUT_URL'				=> '',
				'STATUS_BACKUP_HELP_TEXT'			=> $this->user->lang['STATUS_BACKUP_HELP_TEXT_NO'],
				'STATUS_BACKUP_ID'					=> "id_".rand(1,10000).'_'.rand(1,10000),
				'STATUS_BACKUP_URL_TARGET' 			=> false,
			));
		}
		
		$reports = $params['reports'];
		
		if(!count($reports))
		{
			$this->template->assign_vars(array(
				'REPORT_FLAG' => true,
			));
		} else 
		{
			foreach($reports as $item => $item_array)
			{
				$keys = array_keys($item_array);
				$this->template->assign_block_vars('item1.item2', array(
						'REPORT_'.strtoupper($keys[0])  => $item_array[$keys[0]],
						'REPORT_'.strtoupper($keys[1])  => $item_array[$keys[1]],
						'REPORT_'.strtoupper($keys[2])  => $item_array[$keys[2]],
				));
			}
		}
		
		if ($params['membership'] == 'free') 
		{
			$this->template->assign_vars(array(
				'REPORTS_INFO_TYPE_MES'				=> 'yellow',
				'REPORTS_INFO_TYPE_ICON'			=> 'info',
				'REPORTS_INFO_HEADER'				=> $this->user->lang['REPORTS_INFO_HEADER_NO'],
				'REPORTS_INFO_MES'					=> $this->user->lang['REPORTS_INFO_MES_NO'],
				'REPORTS_INFO_BUT_TEXT'				=> $this->user->lang['STATUS_VERSION_BUT_TEXT_TEXT'],
				'REPORTS_INFO_BUT_URL'				=> 'https://www.siteguarding.com/en/buy-service/antivirus-site-protection',
				'REPORTS_INFO_HELP_TEXT'			=> '',
				'REPORTS_INFO_ID'					=> "id_".rand(1,10000).'_'.rand(1,10000),
				'REPORTS_INFO_URL_TARGET' 			=> true,
			));
		}
		
		if ( $params['last_scan_files_counters']['main'] == 0 || $params['last_scan_files_counters']['heuristic'] == 0 )
		{
			$this->template->assign_vars(array(
				'REPORT_NO_FILES' => true,
			));
		}
		
		if (count($params['last_scan_files']['main']))
		{
			if ($params['membership'] !== 'trial'){
				foreach ($params['last_scan_files']['main'] as $k => $tmp_file)
				{
					if (!file_exists($this->dir_helper->get_root_path() . $tmp_file)) unset($params['last_scan_files']['main'][$k]);
				} 
			}
			
			if (count($params['last_scan_files']['main']) > 0)
			{
				
				$this->template->assign_vars(array(
					'REPORT_MAIN_FILES_FLAG' => true,
				));
				
				foreach ($params['last_scan_files']['main'] as $tmp_file)
				{
					$this->template->assign_block_vars('mainfile', array(
						'REPORT_MAIN_FILE'	=> $tmp_file,
					));
				}
			}
		}
		
		if (count($params['last_scan_files']['heuristic']))
		{
			if ($params['membership'] !== 'trial'){
				foreach ($params['last_scan_files']['heuristic'] as $k => $tmp_file)
				{
					if (!file_exists($this->dir_helper->get_root_path() . $tmp_file)) unset($params['last_scan_files']['heuristic'][$k]);
				}
			}
			
			if (count($params['last_scan_files']['heuristic']) > 0)
			{
				if ($params['whitelist_filters_enabled'] == 1)
				{
					$this->template->assign_vars(array(
						'REPORT_WHITELIST' => true,
				));
				}
				$this->template->assign_vars(array(
					'REPORT_HEURISTIC_FILES_FLAG' => true,
				));
				
				foreach ($params['last_scan_files']['heuristic'] as $tmp_file)
				{
					$this->template->assign_block_vars('heuristicfile', array(
						'REPORT_HEURISTIC_FILE'	=> $tmp_file,
					));
				}
			}
		}
		
	}
	
	public function registration_page()
	{
		$url_to_settings = append_sid("index." . $this->php_ext . "?" . str_replace("mode=antivirus","mode=settings",$this->user->page['query_string']));
		
		$this->template->assign_vars(array(
			'U_ACTION'			=> $this->u_action,
			'REGISTERED_TEXT'	=> sprintf($this->user->lang['ACP_ALREADY_REGISTERED'],$url_to_settings),
			'DOMAIN'			=> generate_board_url(true),
			'EMAIL'				=> $this->user->data['user_email'],
			'EXT_IMG_PATH'		=> $this->dir_helper->get_img_path(),
		));
		
	}
	
	public function set_page_url($u_action)
	{
		$this->u_action = $u_action;
	}
	
	public function registration($domain,$email)
	{
		return $this->helper->send_registration($domain,$email);
	}
	
	public function avp_refresh_status()
	{
		$data = array('cache_license_info_time' => 0);
		$this->sql_helper->set_extra_params($data);
	}
	
	public function check_firewall()
	{
		$path = $this->dir_helper->get_root_path();
		$firewall_file = $path . 'webanalyze/firewall/firewall.' . $this->php_ext;
		if(file_exists($firewall_file))
		{
			return true;
		}else
		{
			return false;
		}
	}
	
}
